#
# spec file for package python-django-tables2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-django-tables2
Version:        2.7.0
Release:        3.1
Summary:        Table/data-grid framework for Django
License:        BSD-2-Clause
URL:            https://github.com/jieter/django-tables2/
Source:         https://github.com/jieter/django-tables2/archive/v%{version}.tar.gz#/django-tables2-%{version}.tar.gz
# PATCH-FEATURE-OPENSUSE python-django-tables2-tests-noxls.patch -- Disable XLS export tests
Patch0:         python-django-tables2-tests-noxls.patch
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Django >= 4.2
Suggests:       python-tablib
BuildArch:      noarch
# SECTION test requirements, see requirements/common.pip
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module Django >= 4.2}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module django-filter >= 2.3.0}
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module openpyxl}
BuildRequires:  %{python_module psycopg2}
BuildRequires:  %{python_module pytz}
BuildRequires:  %{python_module tablib}
# /SECTION
%python_subpackages

%description
Simplifies the task of turning sets of data into HTML tables. It has native
support for pagination and sorting. It does for HTML tables what django.forms
does for HTML forms.

%prep
%autosetup -p1 -n django-tables2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%python_find_lang django

%check
%python_exec ./manage.py test -v 2

%files %{python_files} -f %{python_prefix}-django.lang
%doc README.md CHANGELOG.md
%license LICENSE
%{python_sitelib}/django_tables2
%{python_sitelib}/django_tables2-%{version}.dist-info

%changelog
* Mon Jan 20 2025 Ben Greiner <code@bnavigator.de>
- Test suite: tablib extras need to be installed explicitly
- Add python-django-tables2-tests-noxls.patch
  * Remove xlwt related tests
- Build PEP517
- Find lang
* Thu Oct 31 2024 pgajdos@suse.com
- does not require python-fudge for build
- requires python-pytz for build
* Wed Dec  6 2023 Dirk Müller <dmueller@suse.com>
- update to 2.7.0:
  * Update docs dependencies; fix docs search; add
    readthedocs.yaml (#935)
  * Add example on how to use `Accessor` to documentation in
    `custom-data.rst` (#917) by @ruddra
  * Use pre-commit in ci, add isort, flake8, pyupgrade (#932)
  * Add support for Django 5.0 and Python 3.12 (#930)
  * Add missing `{%% load l10n %%}` in templates (#919) by
    @tvanekeris
* Sat Jul  1 2023 Dirk Müller <dmueller@suse.com>
- update to 2.6.0:
  * Fix bootstrap5-responsive template to extend bootstrap5
  * Add support for django 4.2
  * Drop python 3.7 and django 4.0 support (#920)
* Sun Apr 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.3:
  * Assign request to table before anything else in
    `RequestConfig.configure()` (#888) fixes: #865
  * Add type hints to get_context_data (#895) by @mschoettle
  * Document hidden table attributes setting (#897) by
    @mschoettle
  * Fix building of the docs (#900) by @danielroseman
  * Add template bootstrap5-responsive.html (#896) by @mschoettle
* Thu Feb 16 2023 Dirk Müller <dmueller@suse.com>
- update to 2.5.2:
  * Assign `request` to table before anything else in
    `RequestConfig.configure()` (#888) fixes: #865
* Sun Jan  8 2023 John Vandenberg <jayvdb@gmail.com>
- Remove python-django-tables2-no-mock.patch merged upstream
- Update to v2.5.1
  * `TableMixinBase`: implement `get_paginate_by`
- from v2.5.0
  * Dropped support for python 3.6, added support for python 3.11
  * Add django_tables2/bootstrap4-responsive.html
  * Pass record/value to `LinkColumn`'s attrs callables too
  * Add template `bootstrap5.html` to support bootstrap 5
* Thu May 12 2022 pgajdos@suse.com
- do not require python-mock for build
- added patches
  fix https://github.com/jieter/django-tables2/issues/843
  + python-django-tables2-no-mock.patch
* Fri Dec 24 2021 John Vandenberg <jayvdb@gmail.com>
- Prevent building on Leap Python 3.6
- Update to v2.4.1
  * Add Persian (Farsi) locale
  * Improved error message if openpyxl is not installed
  * Use correct mime type for xlsx
  * Add support for django 4.0, drop support for python 3.5
- from v2.4.0
  * Add support for django 3.2 and python 3.9, drop support for django 3.0
  * Add Django 3.0 and 3.1 trove classifiers
  * Strip leading and trailing whitespace from TemplateColumn.value()
  * Providing link for django-bootstrap3
  * Fix for crash on windows while deleting temp file
* Tue May 18 2021 Dominique Leuenberger <dimstar@opensuse.org>
- Skip python36 build: no pandas
* Tue Jan 19 2021 John Vandenberg <jayvdb@gmail.com>
- Update to v2.3.4
  * Removed deprecation warnings with django 3.1 regarding JSONField
- from v2.3.3
  * Use `table.default` for empty `ManyToMany` relations
  * Pass record/value to `CheckboxColumn`'s `attrs` callables too
- from v2.3.2
  * Fix popping the extra_context of TemplateColumn
  * Fix typo for the translation of the word 'next' in greek
  * Add `format_html` import to prevent `NameError`
  * Fixed Russian translation
* Sat Jun 27 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Thu Apr 23 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.3.1
  /usr/share/doc/packages/python*-django-tables2/CHANGELOG.md
* Sat Jan 18 2020 Marcus Rueckert <mrueckert@suse.de>
- Update to 2.2.1
  /usr/share/doc/packages/python*-django-tables2/CHANGELOG.md
* Thu Jul  4 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 2.0.6
  No changelog provided
* Fri Mar  1 2019 Daniel Molkentin <daniel.molkentin@suse.com>
- Update to 2.0.5
  No changelog provided
* Wed Feb  7 2018 daniel.molkentin@suse.com
- Initial checkin
